pro irac_warm_correct_pulldown_bcdlist, reqkey, ch

;+-
;
; NAME:
;   IRAC_WARM_CORRECT_PULLDOWN_BCDLIST
;
; PURPOSE:
;   Apply column pulldown corrector to a list of BCDs
;
; INPUTS:
;   reqkey: AOR number of BCDs list
;   ch: IRAC channel - ch1 (3.6um) or ch2 (4.5um)
; 
; OUTPUTS: 
;   list of correctes BCD, BUNC and BIMSK files (corr_*_bcd.fits, corr_*_bunc.fits, 
;   corr_*_bimsk.fits)     
;
; NOTE:
;
;  - The routine assumes that the input BCD, BUNC and BIMSK lists have been created 
;    beforehand using the Unix command:
;
;    ls  'r35320064/ch1/bcd/SPITZER_I1_35320064*_bcd.fits'  >  r35320064_ch1_bcd.lis
;    ls  'r35320064/ch1/bcd/SPITZER_I1_35320064*_bunc.fits'  >  r35320064_ch1_bunc.lis
;    ls  'r35320064/ch1/bcd/SPITZER_I1_35320064*_bimsk.fits'  >  r35320064_ch1_bimsk.lis
;
;
; EXAMPLE:
;    To run the code:
;
;     irac_warm_correct_pulldown_bcdlist,35320064 ,1
;
; HISTORY:
;    R. Paladini, 10 January 2011
;
;+-


readcol,'r'+strtrim(reqkey,2) + '_ch' + strtrim(ch,2) + '_bcd.lis', format='a', ifiles
readcol,'r'+strtrim(reqkey,2) + '_ch' + strtrim(ch,2) + '_bunc.lis', format='a', sfiles
readcol,'r'+strtrim(reqkey,2) + '_ch' + strtrim(ch,2) + '_bimsk.lis', format='a', mfiles

;

pre='corr_'     
ofiles=strarr(n_elements(ifiles))
osfiles=strarr(n_elements(ifiles))
omfiles=strarr(n_elements(ifiles))
for j = 0L, n_elements(ifiles)-1 do begin

 pos1 = strpos(ifiles(j), 'S')
 ofiles(j) = strmid(ifiles(j),0, pos1 ) + pre + strmid(ifiles(j), pos1, 50)


 ;

 pos2 = strpos(sfiles(j), 'S')
 osfiles(j) = strmid(sfiles(j),0, pos2 ) + pre + strmid(sfiles(j), pos2, 50)


 ;

 pos3 = strpos(mfiles(j), 'S')
 omfiles(j) = strmid(mfiles(j),0, pos3 ) + pre + strmid(mfiles(j), pos3, 50)


endfor

openw,1,'r'+strtrim(reqkey,2) + '_ch' + strtrim(ch,2) + '_corr_bcd.lis'
printf,1,ofiles
close,1

openw,2,'r'+strtrim(reqkey,2) + '_ch' + strtrim(ch,2) + '_corr_bunc.lis'
printf,2,osfiles
close,2

openw,3,'r'+strtrim(reqkey,2) + '_ch' + strtrim(ch,2) + '_corr_bimsk.lis'
printf,3,omfiles
close,3


; running pulldown

n = n_elements(ifiles)
for i=0,n-1 do begin 

  print,'i =', i
  print,'ifiles(i) =', ifiles(i)
  ifile = ifiles(i) & ofile = ofiles(i)
  sfile = sfiles(i) & osfile = osfiles(i)
  mfile = mfiles(i) & omfile = omfiles(i)


  irac_warm_correct_pulldown, ifile, sfile, mfile, ofile, osfile, $
                             omfile, /pthres

  print,''

endfor


end
